==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/SprawozdaniePodpowiedzWartosc.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class SprawozdaniePodpowiedzWartosc extends GenericDPSObject {
    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.SPRAWOZDANIE_PODPOWIEDZ_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long sprawozdaniePodpowiedzId;

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.WARTOSC_S
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String wartoscS;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.SPRAWOZDANIE_PODPOWIEDZ_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSprawozdaniePodpowiedzId() {
        return sprawozdaniePodpowiedzId;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.SPRAWOZDANIE_PODPOWIEDZ_ID
     *
     * @param sprawozdaniePodpowiedzId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSprawozdaniePodpowiedzId(Long sprawozdaniePodpowiedzId) {
        this.sprawozdaniePodpowiedzId = sprawozdaniePodpowiedzId;
    }

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.WARTOSC_S
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SprawozdaniePodpowiedzWartosc other = (SprawozdaniePodpowiedzWartosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSprawozdaniePodpowiedzId() == null ? other.getSprawozdaniePodpowiedzId() == null : this.getSprawozdaniePodpowiedzId().equals(other.getSprawozdaniePodpowiedzId()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSprawozdaniePodpowiedzId() == null) ? 0 : getSprawozdaniePodpowiedzId().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", sprawozdaniePodpowiedzId=").append(sprawozdaniePodpowiedzId);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/SprawozdaniePodpowiedzWartosc.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class SprawozdaniePodpowiedzWartosc extends GenericDPSObject {
    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.SPRAWOZDANIE_PODPOWIEDZ_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long sprawozdaniePodpowiedzId;

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.WARTOSC_S
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String wartoscS;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.SPRAWOZDANIE_PODPOWIEDZ_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSprawozdaniePodpowiedzId() {
        return sprawozdaniePodpowiedzId;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.SPRAWOZDANIE_PODPOWIEDZ_ID
     *
     * @param sprawozdaniePodpowiedzId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSprawozdaniePodpowiedzId(Long sprawozdaniePodpowiedzId) {
        this.sprawozdaniePodpowiedzId = sprawozdaniePodpowiedzId;
    }

    /**
     * @return SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.WARTOSC_S
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getWartoscS() {
        return wartoscS;
    }

    /**
     * SPRAWOZDANIE_PODPOWIEDZ_WARTOSC.WARTOSC_S
     *
     * @param wartoscS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartoscS(String wartoscS) {
        this.wartoscS = wartoscS == null ? null : wartoscS.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        SprawozdaniePodpowiedzWartosc other = (SprawozdaniePodpowiedzWartosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSprawozdaniePodpowiedzId() == null ? other.getSprawozdaniePodpowiedzId() == null : this.getSprawozdaniePodpowiedzId().equals(other.getSprawozdaniePodpowiedzId()))
            && (this.getWartoscS() == null ? other.getWartoscS() == null : this.getWartoscS().equals(other.getWartoscS()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSprawozdaniePodpowiedzId() == null) ? 0 : getSprawozdaniePodpowiedzId().hashCode());
        result = prime * result + ((getWartoscS() == null) ? 0 : getWartoscS().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", sprawozdaniePodpowiedzId=").append(sprawozdaniePodpowiedzId);
        sb.append(", wartoscS=").append(wartoscS);
        sb.append("]");
        return sb.toString();
    }
}
